@@ -45,8 +45,11 @@ sub CurrentSong
 			'length'=> ::SONG_LENGTH,
 			track	=> ::SONG_TRACK,
 			disc	=> ::SONG_DISC,
+			path	=> ::SONG_PATH,
+			file	=> ::SONG_FILE,
 		);
 	$_=$::Songs[$::SongID][$_] for values %h;
+	$h{album_picture}= $::Album{ $h{album} }[::AAPIXLIST] || '';
 	#warn "$h{title}\n";
 	return \%h;
 }
@@ -91,8 +94,8 @@ sub GetAlbumCoverData
 	my $file=$ref->[::AAPIXLIST];
 	return undef unless -r $file;
 	my $data;
-	if ($file=~m/\.mp3/i)
-	{	$data=ReadTag::PixFromMP3($file);
+	if ($file=~m/\.(?:mp3|flac)$/i)
+	{	my $data=ReadTag::PixFromMusicFile($file);
 	}
 	else
 	{	open my$fh,'<',$file; binmode $fh;
@@ -102,6 +105,14 @@ sub GetAlbumCoverData
 	return [map ord,split //, $data];
 }
 
+dbus_method(CopyFields => [['struct', 'string', 'string']], ['bool']);
+#copy stats fields from one song to another
+#1st arg : filename of ID of source, 2nd arg filename or ID of dest, both must be in the library
+sub CopyFields
+{	my ($self,$array)=@_;
+	::CopyFields(@$array);
+}
+
 dbus_signal('SongChanged', ['uint32']);
 my $lasttime;
 sub SongChanged
@@ -146,7 +157,8 @@ sub DBus_mainloop_hack
 		for my $fd (keys %{$reactor->{fds}{$type2}})
 		{	#warn "$fd $type2";
 			Glib::IO->add_watch($fd,$type1,
-			sub{	$reactor->{fds}{$type2}{$fd}{callback}->invoke;
+			sub{	my $cb=$reactor->{fds}{$type2}{$fd}{callback};
+				$cb->invoke if $cb;
 				$_->invoke for $reactor->_dispatch_hook;
 				1;
 			   }) if $reactor->{fds}{$type2}{$fd}{enabled};
